<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it">
<context>
    <name>ClientSSL</name>
    <message>
        <location filename="../clientssl.cpp" line="248"/>
        <source>Connected to host</source>
        <translation type="obsolete">Connesso all&apos;host</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="264"/>
        <source>Socket error</source>
        <translation type="obsolete">Errore del socket</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="277"/>
        <source>Connection closed</source>
        <translation type="obsolete">Connessione terminata</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="143"/>
        <source>Host not found !</source>
        <translation type="obsolete">Host non trovto !</translation>
    </message>
</context>
<context>
    <name>ClientSocket</name>
    <message>
        <location filename="../clientsocket.cpp" line="434"/>
        <source>Properties</source>
        <translation type="obsolete">Proprieta&apos;</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="408"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Spedire il messaggio a tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="418"/>
        <source>Send out message to</source>
        <translation type="obsolete">Spedire il messaggio a</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="428"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Disconnettere utente</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Si</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;No</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="499"/>
        <source>Message to send</source>
        <translation type="obsolete">Messaggio da inviare</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="527"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Messaggio da inviare a %1:</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="561"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Si vuole davvero disconnettere l&apos;utente %1 ?</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="153"/>
        <source>Host not found !</source>
        <translation type="obsolete">Host non trovto !</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Machine</source>
        <translation>Macchina</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="108"/>
        <source>Open File</source>
        <translation>Apri il file</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <location filename="../mainwindows.cpp" line="68"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">Client QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="86"/>
        <source>Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="88"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="172"/>
        <source>Minimize</source>
        <translation>Minimizza</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="93"/>
        <source>Quit</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="170"/>
        <source>Restore</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="245"/>
        <source>Thanks to:</source>
        <translation>Ringraziamenti a:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="259"/>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="291"/>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="342"/>
        <source>Text not found.</source>
        <translation>Testo non trovato.</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="380"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="381"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>L&apos;utente %1 ha aperto il file %2 (%3)</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="392"/>
        <source>CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="504"/>
        <source>Message to send</source>
        <translation>Messaggio da inviare</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="532"/>
        <source>Message to send to %1:</source>
        <translation>Messaggio da inviare a %1:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="563"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Si vuole davvero disconnettere l&apos;utente %1 ?</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;Yes</source>
        <translation>&amp;Si</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="618"/>
        <source>Properties</source>
        <translation>Proprieta&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="592"/>
        <source>Send out message to all users</source>
        <translation>Spedire il messaggio a tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="602"/>
        <source>Send out message to</source>
        <translation>Spedire il messaggio a</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="612"/>
        <source>Disconnect user</source>
        <translation>Disconnettere utente</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="720"/>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="723"/>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="725"/>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <location filename="../configure.ui" line="19"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="325"/>
        <source>Autoconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="332"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Indirizzio dell&apos;host predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="309"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nome utente predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="355"/>
        <source>Host Address</source>
        <translation>Indirizzo dell&apos;host</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="62"/>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervallo:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="238"/>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="215"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="345"/>
        <source>Username (default :  username = root)</source>
        <translation>Nome utente (predefinito :  nome utente = root)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="190"/>
        <source>Log SMB/CIFS activities</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="180"/>
        <source>Status notification messages</source>
        <translation>Stato messaggi di notifica</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="107"/>
        <source>Notifications and log</source>
        <translation>Notifiche e log</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="125"/>
        <source>Limit log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="154"/>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="170"/>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="31"/>
        <source>Smbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="75"/>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="88"/>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="91"/>
        <source>Show hidden shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="291"/>
        <source>Connection</source>
        <translation>Connessione</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="322"/>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="177"/>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="256"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="265"/>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="272"/>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <location filename="../form_smbstatus.ui" line="13"/>
        <source>qtsmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="167"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="188"/>
        <source>&amp;About QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="205"/>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="117"/>
        <source>Connect/Disconnect</source>
        <translation>Connetti/Disconnetti</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="61"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="223"/>
        <source>&amp;Configure client</source>
        <translation>&amp;Configura client</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="159"/>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="234"/>
        <source>&amp;Machine</source>
        <translation>&amp;Macchina</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="245"/>
        <source>&amp;User</source>
        <translation>&amp;Utente</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="256"/>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="267"/>
        <source>&amp;Locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="278"/>
        <source>&amp;Next</source>
        <translation>&amp;Avanti</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="284"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="292"/>
        <source>&amp;Find text</source>
        <translation>&amp;Trova testo</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="298"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="148"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="208"/>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="226"/>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="237"/>
        <source>Search machine</source>
        <translation>Cerca macchina</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="248"/>
        <source>Search user</source>
        <translation>Cerca utente</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="259"/>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="270"/>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="281"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="295"/>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="307"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="310"/>
        <source>Quit QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="324"/>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nnetti</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="315"/>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="191"/>
        <source>About QtSmbstatus</source>
        <translation>Informazioni su QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <location filename="../log.ui" line="13"/>
        <source>View Activities</source>
        <translation>Visualizza attività</translation>
    </message>
    <message>
        <location filename="../log.ui" line="124"/>
        <source>View/hide shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.ui" line="156"/>
        <source>View/hide files</source>
        <translation>Visualizza/nascondi i file</translation>
    </message>
    <message>
        <location filename="../log.ui" line="196"/>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <location filename="../log.ui" line="41"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.ui" line="104"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../log.ui" line="70"/>
        <source>Save log</source>
        <translation>Salva log</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <location filename="../login_dialog.ui" line="120"/>
        <source>login</source>
        <translation>accedi</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="149"/>
        <source>exit</source>
        <translation>esci</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="27"/>
        <source>Username</source>
        <translation>Nome  utente</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="49"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="62"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="13"/>
        <source>Connect to qtsmbstatus server</source>
        <translation>Connettiti al server qtsmbstatus</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <location filename="../main_windows.cpp" line="627"/>
        <source>Text not found.</source>
        <translation type="obsolete">Testo non trovato.</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="70"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">Client QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="310"/>
        <source>Connect</source>
        <translation>Connettiti</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="177"/>
        <source>Minimize</source>
        <translation type="obsolete">Minimizza</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="82"/>
        <source>Quit</source>
        <translation type="obsolete">Chiudi</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="175"/>
        <source>Restore</source>
        <translation type="obsolete">Ripristina</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="305"/>
        <source>Disconnect</source>
        <translation>Disconetti</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="666"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="obsolete">L&apos;utente %1 ha aperto il file %2 (%3)</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="91"/>
        <source>Impossible to know samba version</source>
        <translation type="obsolete">Impossibile conoscere la versione di samba</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="356"/>
        <source>Invalid login or password !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="519"/>
        <source>Thanks to:</source>
        <translation type="obsolete">Ringraziamenti a:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="77"/>
        <source>Configure</source>
        <translation type="obsolete">Configura</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="576"/>
        <source>Find text</source>
        <translation type="obsolete">Trova testo</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="469"/>
        <source>Search machine</source>
        <translation type="obsolete">Cerca macchina</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="479"/>
        <source>Search user</source>
        <translation type="obsolete">Cerca utente</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="198"/>
        <source>Connection in progress on %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="223"/>
        <source>Connected to host</source>
        <translation>Connesso all&apos;host</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="241"/>
        <source>Connection closed</source>
        <translation>Connessione terminata</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="965"/>
        <source>Properties</source>
        <translation type="obsolete">Proprieta&apos;</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="939"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Spedire il messaggio a tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="949"/>
        <source>Send out message to</source>
        <translation type="obsolete">Spedire il messaggio a</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="959"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Disconnettere utente</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1031"/>
        <source>Message to send</source>
        <translation type="obsolete">Messaggio da inviare</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1057"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Messaggio da inviare a %1:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1089"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Si vuole davvero disconnettere l&apos;utente %1 ?</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Si</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;No</translation>
    </message>
</context>
</TS>
